Author: AlbrechtS
Date: 2009-03-22 12:21:34 -0700 (Sun, 22 Mar 2009)
New Revision: 6712
Log:
fixed a typo

Modified:
   branches/branch-1.3/src/Fl.cxx
   branches/branch-1.3/src/Fl_Gl_Choice.cxx
   branches/branch-1.3/src/Fl_Menu.cxx
   branches/branch-1.3/src/Fl_Menu_add.cxx
   branches/branch-1.3/src/Fl_Tooltip.cxx
   branches/branch-1.3/src/Fl_arg.cxx
   branches/branch-1.3/src/Fl_x.cxx
   branches/branch-1.3/src/fl_color.cxx
   branches/branch-1.3/src/fl_scroll_area.cxx
   branches/branch-1.3/src/fl_set_fonts_x.cxx
   branches/branch-1.3/src/fl_utf.c
   branches/branch-1.3/src/forms_fselect.cxx

Modified: branches/branch-1.3/src/Fl.cxx
===================================================================
--- branches/branch-1.3/src/Fl.cxx      2009-03-22 18:19:37 UTC (rev 6711)
+++ branches/branch-1.3/src/Fl.cxx      2009-03-22 19:21:34 UTC (rev 6712)
@@ -1234,7 +1234,7 @@
 // FL_SHOW and FL_HIDE are called whenever the visibility of this widget
 // or any parent changes.  We must correctly map/unmap the system's window.
 
-// For top-level windows it is assummed the window has already been
+// For top-level windows it is assumed the window has already been
 // mapped or unmapped!!!  This is because this should only happen when
 // Fl_Window::show() or Fl_Window::hide() is called, or in response to
 // iconize/deiconize events from the system.

Modified: branches/branch-1.3/src/Fl_Gl_Choice.cxx
===================================================================
--- branches/branch-1.3/src/Fl_Gl_Choice.cxx    2009-03-22 18:19:37 UTC (rev 
6711)
+++ branches/branch-1.3/src/Fl_Gl_Choice.cxx    2009-03-22 19:21:34 UTC (rev 
6712)
@@ -46,7 +46,7 @@
 
 static Fl_Gl_Choice *first;
 
-// this assummes one of the two arguments is zero:
+// this assumes one of the two arguments is zero:
 // We keep the list system in Win32 to stay compatible and interpret
 // the list later...
 Fl_Gl_Choice *Fl_Gl_Choice::find(int m, const int *alistp) {

Modified: branches/branch-1.3/src/Fl_Menu.cxx
===================================================================
--- branches/branch-1.3/src/Fl_Menu.cxx 2009-03-22 18:19:37 UTC (rev 6711)
+++ branches/branch-1.3/src/Fl_Menu.cxx 2009-03-22 19:21:34 UTC (rev 6712)
@@ -423,7 +423,7 @@
 
   m->draw(xx, yy, ww, hh, button, n==selected);
 
-  // the shortcuts and arrows assumme fl_color() was left set by draw():
+  // the shortcuts and arrows assume fl_color() was left set by draw():
   if (m->submenu()) {
     int sz = (hh-7)&-2;
     int y1 = yy+(hh-sz)/2;

Modified: branches/branch-1.3/src/Fl_Menu_add.cxx
===================================================================
--- branches/branch-1.3/src/Fl_Menu_add.cxx     2009-03-22 18:19:37 UTC (rev 
6711)
+++ branches/branch-1.3/src/Fl_Menu_add.cxx     2009-03-22 19:21:34 UTC (rev 
6712)
@@ -120,7 +120,7 @@
   // split at slashes to make submenus:
   for (;;) {
 
-    // leading slash makes us assumme it is a filename:
+    // leading slash makes us assume it is a filename:
     if (*mytext == '/') {item = mytext; break;}
 
     // leading underscore causes divider line:

Modified: branches/branch-1.3/src/Fl_Tooltip.cxx
===================================================================
--- branches/branch-1.3/src/Fl_Tooltip.cxx      2009-03-22 18:19:37 UTC (rev 
6711)
+++ branches/branch-1.3/src/Fl_Tooltip.cxx      2009-03-22 19:21:34 UTC (rev 
6712)
@@ -209,7 +209,7 @@
 
 // Get ready to display a tooltip. The widget and the xywh box inside
 // it define an area the tooltip is for, this along with the current
-// mouse position places the tooltip (the mouse is assummed to point
+// mouse position places the tooltip (the mouse is assumed to point
 // inside or near the box).
 /**
   You may be able to use this to provide tooltips for internal pieces

Modified: branches/branch-1.3/src/Fl_arg.cxx
===================================================================
--- branches/branch-1.3/src/Fl_arg.cxx  2009-03-22 18:19:37 UTC (rev 6711)
+++ branches/branch-1.3/src/Fl_arg.cxx  2009-03-22 19:21:34 UTC (rev 6712)
@@ -336,7 +336,7 @@
       //  if (mh > gh) gh = mh;
       Fl_Widget *r = resizable();
       if (!r) resizable(this);
-      // for WIN32 we assumme window is not mapped yet:
+      // for WIN32 we assume window is not mapped yet:
       if (fl & (XValue | YValue))
        x(-1), resize(gx,gy,gw,gh);
       else

Modified: branches/branch-1.3/src/Fl_x.cxx
===================================================================
--- branches/branch-1.3/src/Fl_x.cxx    2009-03-22 18:19:37 UTC (rev 6711)
+++ branches/branch-1.3/src/Fl_x.cxx    2009-03-22 19:21:34 UTC (rev 6712)
@@ -1447,7 +1447,7 @@
 
     if (win->border()) {
       // ensure border is on screen:
-      // (assumme extremely minimal dimensions for this border)
+      // (assume extremely minimal dimensions for this border)
       const int top = 20;
       const int left = 1;
       const int right = 1;
@@ -1696,7 +1696,7 @@
 //
 // On XFree86 (and prehaps all X's) this has a problem if the window
 // is resized while a save-behind window is atop it.  The previous
-// contents are restored to the area, but this assummes the area
+// contents are restored to the area, but this assumes the area
 // is cleared to background color.  So this is disabled in this version.
 // Fl_Window *fl_boxcheat;
 static inline int can_boxcheat(uchar b) {return (b==1 || (b&2) && b<=15);}

Modified: branches/branch-1.3/src/fl_color.cxx
===================================================================
--- branches/branch-1.3/src/fl_color.cxx        2009-03-22 18:19:37 UTC (rev 
6711)
+++ branches/branch-1.3/src/fl_color.cxx        2009-03-22 19:21:34 UTC (rev 
6712)
@@ -302,7 +302,7 @@
     xmap.pixel = p.pixel;
   } else {
     // However, if that XAllocColor fails, I have to give up and
-    // assumme the pixel is ok for the duration of the program.  This
+    // assume the pixel is ok for the duration of the program.  This
     // is due to bugs (?) in the Solaris X and some X terminals
     // where XAllocColor *always* fails when the colormap is full,
     // even if we ask for a color already in it...

Modified: branches/branch-1.3/src/fl_scroll_area.cxx
===================================================================
--- branches/branch-1.3/src/fl_scroll_area.cxx  2009-03-22 18:19:37 UTC (rev 
6711)
+++ branches/branch-1.3/src/fl_scroll_area.cxx  2009-03-22 19:21:34 UTC (rev 
6712)
@@ -91,7 +91,7 @@
   for (;;) {
     XEvent e; XWindowEvent(fl_display, fl_window, ExposureMask, &e);
     if (e.type == NoExpose) break;
-    // otherwise assumme it is a GraphicsExpose event:
+    // otherwise assume it is a GraphicsExpose event:
     draw_area(data, e.xexpose.x, e.xexpose.y,
              e.xexpose.width, e.xexpose.height);
     if (!e.xgraphicsexpose.count) break;

Modified: branches/branch-1.3/src/fl_set_fonts_x.cxx
===================================================================
--- branches/branch-1.3/src/fl_set_fonts_x.cxx  2009-03-22 18:19:37 UTC (rev 
6711)
+++ branches/branch-1.3/src/fl_set_fonts_x.cxx  2009-03-22 19:21:34 UTC (rev 
6712)
@@ -191,7 +191,7 @@
     if (*b != '-') return -1;
   }
 
-  // skip the foundry (assumme equal):
+  // skip the foundry (assume equal):
   for (a++; *a && *a++!='-';);
   for (b++; *b && *b++!='-';);
 

Modified: branches/branch-1.3/src/fl_utf.c
===================================================================
--- branches/branch-1.3/src/fl_utf.c    2009-03-22 18:19:37 UTC (rev 6711)
+++ branches/branch-1.3/src/fl_utf.c    2009-03-22 19:21:34 UTC (rev 6712)
@@ -211,8 +211,8 @@
   \e start is the start of the string and is used to limit the
   backwards search for the start of a utf8 character.
 
-  \e end is the end of the string and is assummed to be a break
-  between characters. It is assummed to be greater than p.
+  \e end is the end of the string and is assumed to be a break
+  between characters. It is assumed to be greater than p.
 
   This function is for moving a pointer that was jumped to the
   middle of a string, such as when doing a binary search for
@@ -247,8 +247,8 @@
   \e start is the start of the string and is used to limit the
   backwards search for the start of a UTF-8 character.
 
-  \e end is the end of the string and is assummed to be a break
-  between characters. It is assummed to be greater than p.
+  \e end is the end of the string and is assumed to be a break
+  between characters. It is assumed to be greater than p.
 
   If you wish to decrement a UTF-8 pointer, pass p-1 to this.
 */
@@ -655,7 +655,7 @@
     ret = GetACP() == CP_UTF8;
 #else
     char* s;
-    ret = 1; /* assumme UTF-8 if no locale */
+    ret = 1; /* assume UTF-8 if no locale */
     if (((s = getenv("LC_CTYPE")) && *s) ||
        ((s = getenv("LC_ALL"))   && *s) ||
        ((s = getenv("LANG"))     && *s)) {

Modified: branches/branch-1.3/src/forms_fselect.cxx
===================================================================
--- branches/branch-1.3/src/forms_fselect.cxx   2009-03-22 18:19:37 UTC (rev 
6711)
+++ branches/branch-1.3/src/forms_fselect.cxx   2009-03-22 19:21:34 UTC (rev 
6712)
@@ -31,7 +31,7 @@
 #include "flstring.h"
 
 static char fl_directory[1024];
-static const char *fl_pattern;  // assummed passed value is static
+static const char *fl_pattern;  // assumed passed value is static
 static char fl_filename[1024];
 
 char* fl_show_file_selector(const char *message,const char *dir,

_______________________________________________
fltk-commit mailing list
[email protected]
http://lists.easysw.com/mailman/listinfo/fltk-commit

Reply via email to